pub fn test_cloud_home() -> Arc<InMemoryCloudHome>Expand description
An InMemoryCloudHome bound to a fixed Google Drive provider, for the
tests that need a cloud home but do not care which provider it claims to
be.
pub fn test_cloud_home() -> Arc<InMemoryCloudHome>An InMemoryCloudHome bound to a fixed Google Drive provider, for the
tests that need a cloud home but do not care which provider it claims to
be.